@@ -662,6 +662,13 @@ Staging failed for %(nvr)s.
         cmd.extend(['tag', '-d', tag])
         self.log_cmd(cmd, cwd=self.checkout)
 
+    def clean_lookaside_cache(self):
+        if not self.options.keep_lookaside:
+            lookaside_path = os.path.join(self.options.config['lookaside'],
+                                            self.package, self.options.branch)
+            if os.path.exists(lookaside_path):
+                self.logger.warning("Cleaning lookaside cache: %s", lookaside_path)
+                wipe_dir(lookaside_path)
 
 class Stager(BaseProcessor):
     MMD_DEBRAND_RTYPES = [
@@ -750,6 +757,14 @@ will overwrite.", dirname, state)
         cmd = ['git', 'fetch', '-v', git_url, '+refs/*:refs/*']
         try:
             self.log_cmd(cmd, cwd=repo)
+        except CommandError:
+            self.logger.warning('Unable to fetch remote repo')
+            self.logger.warning('Removing local cache: %s', repo)
+            # remove broken/empty dir
+            shutil.rmtree(repo)
+            # reclone repo
+            self.logger.warning('Re-initializing repo')
+            self.init_repo()
         except Exception:
             self.logger.error('Unable to fetch remote repo')
             self.logger.error('Local cache exists: %s', repo)
@@ -942,7 +957,7 @@ If you find this file in a distro specific branch, it means that no content has
         """Import our source srpm/modulemd on the specified branch"""
         # clear our checkout dir
         dst = self.checkout
-        wipe_git_dir(dst)
+        wipe_dir(dst, git=True)
         # confirm that the directory is wiped, because in the duplicate check
         # below, we want to be sure that the duplicate content really came
         # from our exploded srpm
@@ -950,9 +965,9 @@ If you find this file in a distro specific branch, it means that no content has
             if fname != '.git':
                 raise SanityError('Failed to clear checkout')
         sourcedir = os.path.join(dst, 'SOURCES/')
+        os.makedirs(sourcedir) # RPM sources can be empty.
         if self.mmd:
             # move module src to stage dir
-            os.makedirs(sourcedir)
             shutil.copy(self.source_file, os.path.join(sourcedir))
         else:
             # explode our srpm
@@ -967,6 +982,10 @@ If you find this file in a distro specific branch, it means that no content has
                 to_move.append(fname)
         to_move.sort()
 
+        # clean lookaside cache
+        if to_move:
+            self.clean_lookaside_cache()
+
         # move files to lookaside
         meta = open(os.path.join(dst, ".%s.metadata" % self.package), 'w')
         gitignore = open(os.path.join(dst, ".gitignore"), 'w')
@@ -1712,6 +1731,7 @@ class Pusher(BaseProcessor):
         self.push_git(state)
         self.set_state('PUSHED')
         self.notify()
+        self.clean_lookaside_cache()
 
     def check_workdir(self):
         self.workdir = dirname = self.get_workdir()
@@ -2103,9 +2123,9 @@ def relocate_sources(headers, dir):
         os.rename(src, os.path.join(destdir, basename))
 
 
-def wipe_git_dir(dirname):
+def wipe_dir(dirname, git=False):
     for fname in os.listdir(dirname):
-        if fname == '.git':
+        if git and fname == '.git':
             continue
         path = os.path.join(dirname, fname)
         if os.path.isdir(path):
@@ -2115,13 +2135,12 @@ def wipe_git_dir(dirname):
 
 
 def die(msg):
-    self.logger.error(msg)
+    logging.getLogger("altsrc").error(msg)
     sys.exit(1)
 
 
 def setup_logging(options):
-    logger = logging.getLogger("altsrc")
-    logger.setLevel(logging.DEBUG)
+    logger = logging.getLogger()
 
     #determine log levels
     output_log_level = logging.WARN #default
@@ -2141,6 +2160,9 @@ def setup_logging(options):
     file_log_level = min(file_log_level, output_log_level)
     options.file_log_level = file_log_level
 
+    # remove the default handler of root logger
+    logger.handlers = []
+
     # set up handlers
     handler = logging.StreamHandler(sys.stdout)
     handler.setFormatter(logging.Formatter(options.config['log_format']))
@@ -2194,11 +2216,14 @@ def main(args):
                       help=_("keep lookaside sources in staging checkout"))
     parser.add_option("-o", "--option", dest="copts", action="append", metavar="OPT=VALUE",
                       help=_("set config option"))
+    parser.add_option("--keep-lookaside", action="store_true", default=False,
+                      help=_("keep sources in staging lookaside cache"))
     (options, args) = parser.parse_args(args)
 
     options.branch = args[0]
     options.source = args[1]
 
+    logging.basicConfig(level=logging.DEBUG)
     options.config = get_config(options.cfile, options.copts)
 
     logger = setup_logging(options)
